Update of /cvsroot/fink/fink/perlmod/Fink
In directory sc8-pr-cvs1.sourceforge.net:/tmp/cvs-serv26688/perlmod/Fink

Modified Files:
      Tag: shlibs
        ChangeLog PkgVersion.pm Shlibs.pm 
Log Message:
Added AddShlibDeps: instead of {SHLIB_DEPS}

Index: Shlibs.pm
===================================================================
RCS file: /cvsroot/fink/fink/perlmod/Fink/Attic/Shlibs.pm,v
retrieving revision 1.1.2.36
retrieving revision 1.1.2.37
diff -u -d -r1.1.2.36 -r1.1.2.37
--- Shlibs.pm   4 Feb 2005 02:48:22 -0000       1.1.2.36
+++ Shlibs.pm   9 Feb 2005 02:04:28 -0000       1.1.2.37
@@ -100,6 +100,7 @@
        @splits = $pkg->get_splitoffs(1, 1);
 
        # Get depends line and builddepends lines for compares
+       # FIXME add RunTimeDepends to this array
        @deplines = split(/\s*\,\s*/, $pkg->param_default("Depends", ""));
        @builddeps = split(/\s*\,\s*/, $pkg->param_default("BuildDepends", ""));
 
@@ -162,7 +163,6 @@
                                ### Check that a dep isn't already explicitly
                                ### set
                                foreach $depline (@deplines) {
-                                       next if ($depline eq "{SHLIB_DEPS}");
                                        if ($depline =~ /^(\S*)\s*\((.*)\)$/) {
                                                $vers = $2;
                                                $dep = $1;

Index: ChangeLog
===================================================================
RCS file: /cvsroot/fink/fink/perlmod/Fink/ChangeLog,v
retrieving revision 1.305.2.44
retrieving revision 1.305.2.45
diff -u -d -r1.305.2.44 -r1.305.2.45
--- ChangeLog   9 Feb 2005 01:44:16 -0000       1.305.2.44
+++ ChangeLog   9 Feb 2005 02:04:27 -0000       1.305.2.45
@@ -1,3 +1,10 @@
+2005-02-06  Justin F. Hallett  <[EMAIL PROTECTED]>
+
+       * Shlibs.pm: Removed ref to {SHLIB_DEPS} and added comment for upcoming
+       RunTimeDepends
+       * PkgVersion.pm: Removed refs to {SHLIB_DEPS}, added check for
+       AddShlibDeps to run auto adding of depends for deb file creation
+
 2005-02-08  Daniel Macks  <[EMAIL PROTECTED]>
 
        * Engine.pm: Fix plural in package count msg.



-------------------------------------------------------
SF email is sponsored by - The IT Product Guide
Read honest & candid reviews on hundreds of IT Products from real users.
Discover which products truly live up to the hype. Start reading now.
http://ads.osdn.com/?ad_id=6595&alloc_id=14396&op=click
_______________________________________________
Fink-commits mailing list
[email protected]
https://lists.sourceforge.net/lists/listinfo/fink-commits

Reply via email to
Index: PkgVersion.pm
===================================================================
RCS file: /cvsroot/fink/fink/perlmod/Fink/PkgVersion.pm,v
retrieving revision 1.128.2.45
retrieving revision 1.128.2.46
diff -u -d -r1.128.2.45 -r1.128.2.46
--- PkgVersion.pm       9 Feb 2005 01:44:16 -0000       1.128.2.45
+++ PkgVersion.pm       9 Feb 2005 02:04:27 -0000       1.128.2.46
@@ -1281,7 +1281,6 @@
                # declarations have not been violated (of course we only do 
that when generating
                # a 'depends' list, not for 'conflicts').
                foreach $altspecs (@speclist){
-                       next if ($altspecs eq '{SHLIB_DEPS}');
                        ## Determine if it has a multi type depends line thus
                        ## multi pkgs can satisfy the depend and it shouldn't
                        ## warn if certain ones aren't found, as long as any 
one of them is
@@ -1376,7 +1375,6 @@
        }
 
        SPECLOOP: foreach $altspecs (@speclist) {
-               next if ($altspecs eq '{SHLIB_DEPS}');
                $altlist = [];
                @altspec = split(/\s*\|\s*/, $altspecs);
                $found = 0;
@@ -2356,9 +2354,9 @@
                foreach (@$_) {
                        $has_kernel_dep = 1 if /^$kernel(\Z|\s|\()/;
 
-                       ### Add {SHLIB_DEPS} replace code here
-                       ### 1) check for {SHLIB_DEPS} else continue
-                       if (/\{SHLIB_DEPS\}/) {
+                       ### Add shlib depends code here
+                       ### 1) check for 'AddShlibDeps: true' else continue
+                       if ($self->param_boolean("AddShlibDeps")) {
                                print "Writing shared library 
dependencies...\n";
         
                                ### 2) get a list to replace it with
